from wddasylumclaims import LoadKeywords, WebScrape
import argparse
import os
import feather

def main():
    defaultPath = "https://docs.google.com/spreadsheets/d/e/2PACX-1vR8qMS3_t8ibuOkmMwzvJA7CXil3vbeCpbubrCPZByxcPHpCN4eBnsmQslU18E_8uDC6jiuvp5X-aEw/pub?gid=0&single=true&output=csv"

    parser = argparse.ArgumentParser(description='Asylum Claim webscraping')
    parser.add_argument('-f','--filepath', default=defaultPath, help="filepath to csv of keywords or url to google sheet")

    args = vars(parser.parse_args())
    cmd_main(args)

def search(url,keywords):
    # Scrape html page for decision document
    div_name = 'decision-inner'
    decision_html = WebScrape.scrape(url,div_name)
    if (decision_html):
        # Find keywords in document
        keywordLoc,keywordCount = WebScrape.findKeywords(decision_html,keywords)
        return keywordLoc,keywordCount
    else:
        return False,False

def cmd_main(args):
    csv_filepath = args["filepath"]

     # Get keywords from spreadsheet
    known_headers = ["introductory_headings", "unsuccessful", "successful", "ambiguous_outcome", "country","dob"]

    # Get keywords from google sheet
    if ("http" in csv_filepath):
        keywords = LoadKeywords.find_google_sheet(csv_filepath,known_headers)
    else:
        keywords = LoadKeywords.find(csv_filepath,known_headers)


    path = os.path.dirname(os.path.realpath(__file__)) +'\\sample\\case_links.feather'
 
    df = feather.read_dataframe(path)
    url_prefix = "https://tribunalsdecisions.service.gov.uk"

    rows_count,cols_count = df.shape

    print("Starting process...")
    
    for index, row in df.iterrows():
        # get url from feather data
        url_suffix = row['case_links']
        full_url = url_prefix + url_suffix

        #search for keywords in url
        keywordLoc,keywordCount = search(full_url,keywords)
        if (not keywordCount or not keywordLoc):
            print ("unable to grab from website (maybe missing 'decision-inner' div)")
        else:
            print()
            print("Keywords found")
            print("--------------")
            for h in keywordCount.keys():
                print ("{}: {}".format(h,keywordCount[h]))

            print()
            print("Keyword locations [LINE_NUM,COL_NUM]")
            print("------------------------------------")
            for h in keywordLoc.keys():
                print ("{}: {}".format(h,keywordLoc[h]))
        
        print("{}/{}".format(index,rows_count))
        
    print("Process complete")

if __name__ == "__main__":
    main()


from bs4 import BeautifulSoup
import requests
import csv

def scrape(url,div_name):
    resp = requests.get(url)

    soup = BeautifulSoup(resp.content,features="html.parser")

    for div in soup.find_all("div"):
        if (div.get("class") == [div_name]):
            return div

    return False

def findKeywords(div,keywords):
    keywordCount = {}
    keywordLoc = {}
    for h in keywords.keys():
        keywordCount[h] = 0
        keywordLoc[h] = []

    for h in keywords.keys():
        for k in keywords[h]:
            for line_num,line in enumerate(div):
                idx = line.find(k)
                if (idx != None):
                    if (idx > -1):
                        keywordLoc.setdefault(h, []).append([line_num,idx])
                        keywordCount[h] = keywordCount[h] + 1
    return keywordLoc,keywordCount

if __name__ == "__main__":
    url = "https://tribunalsdecisions.service.gov.uk/utiac/pa-05705-2017-a23c9180-6c47-40f3-9294-67754ec19a04"
    div_name = 'decision-inner'
    div_data = scrape(url,div_name)
    print(div_data)


import csv
import os
import requests
from collections import defaultdict

from contextlib import closing

def find(csv_filepath,known_headers=["introductory_headings", "unsuccessful", "successful", "ambiguous_outcome", "country","dob"]):
    #initialise keywords dictionary with known headings
    keywords = {}
    for h in known_headers:
        keywords[h] = []

    with open(csv_filepath, mode='r') as csv_file:
        #read csv
        csv_reader = csv.DictReader(csv_file, delimiter=',')
        #load data into dictionary using headers
        for row in csv_reader:
            for h in known_headers:
                if (row[h]):
                    keywords.setdefault(h, []).append(row[h])
    return keywords

def find_google_sheet(url,known_headers=["introductory_headings", "unsuccessful", "successful", "ambiguous_outcome", "country","dob"]):
    keywords = {}
    for h in known_headers:
        keywords[h] = []

    response = requests.get(url)
    csv_reader = csv.DictReader(response.iter_lines(decode_unicode='utf-8'),delimiter=',')
    for row in csv_reader:
        for h in known_headers:
            if (row[h]):
                keywords.setdefault(h, []).append(row[h])
    return keywords